from .base_enum import BaseEnum


class ESearchAutoMapper(BaseEnum):
    BOTH = True
    AI = False
    NO_AI = None
